==> comptechsoft-vue-foundation-1.0.10.tgz: package/src/~compvuetech/Components/Controls/Searchboxes/Base/Searchbox.js <==
import Control from "../../Control";
import Axios from "../../../../Classes/Axios/Axios"

class Searchbox extends Control {

    constructor(name) {
        super(name)

        this.label = 'My Label (' + this.name + ')'
        this.placeholder = 'My placeholder (' + this.name + ')'

        /**
         * Select 2 options
         */
        this.allowClear = false
        this.templateSelection = null
        this.templateResult = null
        this.endpoint = null
        this.processResults = null

        /**
         * Dupa care coloana se cauta
         */
        this.searchby = null
        this.searchlength = 1
        this.payload = 'aaaa',

        /**
         * Numele componentei modal (de exemplu: roles-modal, ...)
         */
        this.modal = null

        /**
         * Endpoint pentru gasirea unui record in vederea initializarii
         */
        this.findRecordEndpoint = null

        /**
         * Instanta Select2
         */
        this.plugin = null

        /**
         * Componenta la care este atasat
         */
        this.vue = null

        this.initialOption = null
    }

    SetPlaceholder(value) {
        this.placeholder = value
        return this
    }

    SetLabel(value) {
        this.label = value
        return this
    }

    SetEndpoint(value) {
        this.endpoint = value
        return this
    }

    SetSearchBy(value) {
        this.searchby = value
        return this
    }

    SetProcessResults(value) {
        this.processResults = value
        return this
    }

    SetTemplateResult(value){
        this.templateResult = value
        return this
    }

    SetTemplateSelection(value){
        this.templateSelection = value
        return this
    }

    SetFindRecordEndpoint(value) {
        this.findRecordEndpoint = document.head.querySelector('meta[name="base-url"]').content + '/' + value
        return this
    }

    SetModal(value) {
        this.modal = value
        return this
    }

    SetPayload(value) {
        this.payload = value
        return this
    }

    get pluginOptions() {
        let r = {
            placeholder: this.placeholder,
            allowClear: this.allowClear,
            dropdownParent: $('#' + this.id),
        }
        if(this.templateSelection)
        {
            r['templateSelection'] = this.templateSelection
        }
        if(this.templateResult)
        {
            r['templateResult'] = this.templateResult
        }
        r['escapeMarkup'] = function (markup) { 
            return markup; 
        }
        if(this.endpoint)
        {
            let self = this
            r['ajax'] = {
                'url': document.head.querySelector('meta[name="base-url"]').content + '/' + this.endpoint,
                dataType: 'json',
                delay: 250,
                data: function(params) {
                    return {
                        searched: params.term, 
                        fields: self.searchby,
                        length: self.searchlength,
                        payload: self.payload,
                    };
                },
                processResults: function(data, params) {
                    return {
                        results: _.map(data, item => {
                            if(item.hasOwnProperty('html'))
                            {
                                return item
                            }
                            return {
                                id: item.id,
                                text: self.processResults(item),
                                record: item,
                            }
                        }),
                    };
                },
                cache: true
            }
        }
        return r
    }

    CreatePlugin(vue) {
        this.vue = vue
        let i = setInterval( () => {
            let jq = $('#input-' + this.id)
            
            if(jq.length == 1)
            {
                clearInterval(i)
                
                this.plugin = jq.select2(this.pluginOptions)

                this.plugin.on('select2:select', function (e) {
                    let data = e.params.data;
                    vue.$emit('input', data.id)
                })

                this.plugin.on('select2:clear', function (e) {
                    vue.$emit('input', null)
                });

                if(vue.value)
                {
                    this.CreateInitialOption()
                }
            }
        }, 200)
    }

    CreateInitialOption(value) {
        let endpoint = this.findRecordEndpoint

        let axios = new _Classes_Axios_Axios__WEBPACK_IMPORTED_MODULE_1__["default"]().SetEndpoint(endpoint).SetData({id: value}).OnSuccess(() => {
            let response = axios.response
            
            if(response.success)
            {
                let jq = $('#input-' + this.id)
                let find = jq.find("option[value='" + response.record.id + "']").length
                if( ! find )
                {
                    let option = new Option(response.record.text, response.record.id, true, true)
                    this.plugin.append(option).trigger('change')                
                }
                setTimeout( () => {
                    this.plugin.val(response.record.id).trigger('change')

                    this.plugin.trigger({
                        type: 'select2:select',
                        params: {
                            data: response.record,
                        }
                    });
                }, 100)
                
            }            
        })
        axios.Post()
        return this
        
    }

    Clear() {
        this.plugin.val(null).trigger('change')
        this.vue.$emit('input', null)
        return this
    }

}

export default Searchbox

==> comptechsoft-vue-foundation-1.0.12.tgz: package/src/~compvuetech/Components/Controls/Searchboxes/Base/Searchbox.js <==
import Control from "../../Control";
import Axios from "../../../../Classes/Axios/Axios"

class Searchbox extends Control {

    constructor(name) {
        super(name)

        this.label = 'My Label (' + this.name + ')'
        this.placeholder = 'My placeholder (' + this.name + ')'

        /**
         * Select 2 options
         */
        this.allowClear = false
        this.templateSelection = null
        this.templateResult = null
        this.endpoint = null
        this.processResults = null

        /**
         * Dupa care coloana se cauta
         */
        this.searchby = null
        this.searchlength = 1
        this.payload = 'aaaa',

        /**
         * Numele componentei modal (de exemplu: roles-modal, ...)
         */
        this.modal = null

        /**
         * Endpoint pentru gasirea unui record in vederea initializarii
         */
        this.findRecordEndpoint = null

        /**
         * Instanta Select2
         */
        this.plugin = null

        /**
         * Componenta la care este atasat
         */
        this.vue = null

        this.initialOption = null
    }

    SetPlaceholder(value) {
        this.placeholder = value
        return this
    }

    SetLabel(value) {
        this.label = value
        return this
    }

    SetEndpoint(value) {
        this.endpoint = value
        return this
    }

    SetSearchBy(value) {
        this.searchby = value
        return this
    }

    SetProcessResults(value) {
        this.processResults = value
        return this
    }

    SetTemplateResult(value){
        this.templateResult = value
        return this
    }

    SetTemplateSelection(value){
        this.templateSelection = value
        return this
    }

    SetFindRecordEndpoint(value) {
        this.findRecordEndpoint = document.head.querySelector('meta[name="base-url"]').content + '/' + value
        return this
    }

    SetModal(value) {
        this.modal = value
        return this
    }

    SetPayload(value) {
        this.payload = value
        return this
    }

    get pluginOptions() {
        let r = {
            placeholder: this.placeholder,
            allowClear: this.allowClear,
            dropdownParent: $('#' + this.id),
        }
        if(this.templateSelection)
        {
            r['templateSelection'] = this.templateSelection
        }
        if(this.templateResult)
        {
            r['templateResult'] = this.templateResult
        }
        r['escapeMarkup'] = function (markup) { 
            return markup; 
        }
        if(this.endpoint)
        {
            let self = this
            r['ajax'] = {
                'url': document.head.querySelector('meta[name="base-url"]').content + '/' + this.endpoint,
                dataType: 'json',
                delay: 250,
                data: function(params) {
                    return {
                        searched: params.term, 
                        fields: self.searchby,
                        length: self.searchlength,
                        payload: self.payload,
                    };
                },
                processResults: function(data, params) {
                    return {
                        results: _.map(data, item => {
                            if(item.hasOwnProperty('html'))
                            {
                                return item
                            }
                            return {
                                id: item.id,
                                text: self.processResults(item),
                                record: item,
                            }
                        }),
                    };
                },
                cache: true
            }
        }
        return r
    }

    CreatePlugin(vue) {
        this.vue = vue
        let i = setInterval( () => {
            let jq = $('#input-' + this.id)
            
            if(jq.length == 1)
            {
                clearInterval(i)
                
                this.plugin = jq.select2(this.pluginOptions)

                this.plugin.on('select2:select', function (e) {
                    let data = e.params.data;
                    vue.$emit('input', data.id)
                })

                this.plugin.on('select2:clear', function (e) {
                    vue.$emit('input', null)
                });

                if(vue.value)
                {
                    this.CreateInitialOption()
                }

                setTimeout( () => {
                    $('#select2-input-' + this.id + '-container').hover(function () {
                        $(this).removeAttr('title');
                    });
                }, 250)
            }
        }, 200)
    }

    CreateInitialOption(value) {
        let endpoint = this.findRecordEndpoint

        let axios = new Axios().SetEndpoint(endpoint).SetData({id: value}).OnSuccess(() => {
            let response = axios.response
            
            if(response.success)
            {
                let jq = $('#input-' + this.id)
                let find = jq.find("option[value='" + response.record.id + "']").length
                if( ! find )
                {
                    let option = new Option(response.record.text, response.record.id, true, true)
                    this.plugin.append(option).trigger('change')                
                }
                setTimeout( () => {
                    this.plugin.val(response.record.id).trigger('change')

                    this.plugin.trigger({
                        type: 'select2:select',
                        params: {
                            data: response.record,
                        }
                    });
                    
                }, 100)
                
            }            
        })
        axios.Post()
        return this
        
    }

    Clear() {
        if(this.enabled)
        {
            this.plugin.val(null).trigger('change')
            this.vue.$emit('input', null)
        }
        return this
    }

}

export default Searchbox
